@@ -282,8 +282,8 @@ phosh_quick_setting_open_settings_panel (const char *panel)
   g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
 			    G_DBUS_PROXY_FLAGS_NONE,
 			    NULL,
-			    "org.gnome.ControlCenter",
-			    "/org/gnome/ControlCenter",
+			    "org.gnome.Settings",
+			    "/org/gnome/Settings",
 			    "org.gtk.Actions",
 			    NULL,
 			    (GAsyncReadyCallback) create_dbus_proxy_cb,
