@@ -6,7 +6,7 @@
  * Author: Florian Loers <florianloers@mailbox.org>
  */
 
-#define G_LOG_DOMAIN "phosh-run-command-dialog-manager"
+#define G_LOG_DOMAIN "phosh-run-command-manager"
 
 #include "run-command-manager.h"
 #include "run-command-dialog.h"
@@ -17,10 +17,11 @@
 #define KEYBINDING_KEY_RUN_DIALOG "panel-run-dialog"
 
 /**
- * SECTION:run-command-dialog-manager
+ * SECTION:run-command-manager
  * @short_description: Handles the run-command-dialog
  *
- * The interface is responsible to handle the ui parts of a #RunCommandDIalog.
+ * The interface is responsible to handle the non-ui parts of a
+ * #PhoshRunCommandDialog.
  */
 
 typedef struct _PhoshRunCommandManager {
@@ -48,7 +49,7 @@ cleanup_child_process (GPid pid, gint status, void *user_data)
   }
 }
 
-static void
+static gboolean
 run_command (char *command)
 {
   GPid child_pid;
@@ -57,34 +58,50 @@ run_command (char *command)
 
   if (!g_shell_parse_argv (command, NULL, &argv, &error)) {
     g_warning ("Could not parse command: %s\n", error->message);
-    return;
+    return FALSE;
   }
-  if (!g_spawn_async (
-          NULL,
-          argv,
-          NULL,
-          G_SPAWN_DO_NOT_REAP_CHILD |
-              G_SPAWN_SEARCH_PATH |
-              G_SPAWN_STDOUT_TO_DEV_NULL |
-              G_SPAWN_STDERR_TO_DEV_NULL,
-          NULL,
-          NULL,
-          &child_pid,
-          &error)) {
-    g_warning ("Could not run command: %s\n", error->message);
-    return;
+  if (g_spawn_async (NULL,
+                      argv,
+                      NULL,
+                      G_SPAWN_DO_NOT_REAP_CHILD |
+                      G_SPAWN_SEARCH_PATH |
+                      G_SPAWN_STDOUT_TO_DEV_NULL |
+                      G_SPAWN_STDERR_TO_DEV_NULL,
+                      NULL,
+                      NULL,
+                      &child_pid,
+                      &error)) {
+    g_child_watch_add (child_pid, cleanup_child_process, NULL);
+    return TRUE;
   }
-  g_child_watch_add (child_pid, cleanup_child_process, NULL);
+
+  g_warning ("Could not run command: %s\n", error->message);
+  return FALSE;
 }
 
 static void
-on_run_command_dialog_done (PhoshRunCommandManager *self, gboolean cancelled, char *command)
+on_run_command_dialog_submitted (PhoshRunCommandManager *self, char *command)
 {
-  if (!cancelled) {
-    run_command (command);
-  }
-  if (self->dialog)
+  g_autofree char *msg = NULL;
+
+  g_return_if_fail (PHOSH_IS_RUN_COMMAND_DIALOG (self->dialog));
+  g_return_if_fail (command);
+
+  if (run_command (command)) {
     gtk_widget_hide (GTK_WIDGET (self->dialog));
+    g_clear_pointer (&self->dialog, phosh_cp_widget_destroy);
+  } else {
+    msg = g_strdup_printf (_("Running '%s' failed"), command);
+    phosh_run_command_dialog_set_message (self->dialog, msg);
+  }
+}
+
+static void
+on_run_command_dialog_cancelled (PhoshRunCommandManager *self)
+{
+  g_return_if_fail (PHOSH_IS_RUN_COMMAND_DIALOG (self->dialog));
+
+  gtk_widget_hide (GTK_WIDGET (self->dialog));
   g_clear_pointer (&self->dialog, phosh_cp_widget_destroy);
 }
 
@@ -99,30 +116,28 @@ show_run_command_dialog (GSimpleAction *action, GVariant *param, gpointer data)
   dialog = phosh_run_command_dialog_new ();
   self->dialog = PHOSH_RUN_COMMAND_DIALOG (dialog);
   gtk_widget_show (GTK_WIDGET (self->dialog));
-  g_signal_connect_object (self->dialog, "done", G_CALLBACK (on_run_command_dialog_done), self, G_CONNECT_SWAPPED);
+  g_object_connect (self->dialog,
+                    "swapped-object-signal::submitted", G_CALLBACK (on_run_command_dialog_submitted), self,
+                    "swapped-object-signal::cancelled", G_CALLBACK (on_run_command_dialog_cancelled), self,
+                    NULL);
 }
 
 static void
 add_keybindings (PhoshRunCommandManager *self)
 {
-  GStrv bindings;
-  GPtrArray *action_names = g_ptr_array_new ();
-
+  g_auto (GStrv) bindings = NULL;
   g_autoptr (GArray) actions = g_array_new (FALSE, TRUE, sizeof (GActionEntry));
+
   bindings = g_settings_get_strv (self->settings, KEYBINDING_KEY_RUN_DIALOG);
   for (int i = 0; i < g_strv_length (bindings); i++) {
-    GActionEntry entry = {
-        bindings[i],
-        show_run_command_dialog,
-    };
+    GActionEntry entry = { .name = bindings[i], .activate = show_run_command_dialog };
     g_array_append_val (actions, entry);
-    g_ptr_array_add (action_names, bindings[i]);
   }
   phosh_shell_add_global_keyboard_action_entries (phosh_shell_get_default (),
                                                   (GActionEntry *)actions->data,
                                                   actions->len,
                                                   self);
-  self->action_names = (GStrv)g_ptr_array_free (action_names, FALSE);
+  self->action_names = g_steal_pointer (&bindings);
 }
 
 static void
