@@ -60,6 +60,7 @@
 #include "phosh-private-client-protocol.h"
 #include "phosh-wayland.h"
 #include "polkit-auth-agent.h"
+#include "portal-access-manager.h"
 #include "proximity.h"
 #include "quick-setting.h"
 #include "run-command-manager.h"
@@ -77,7 +78,7 @@
 #include "util.h"
 #include "vpn-info.h"
 #include "wifiinfo.h"
-#include "wwaninfo.h"
+#include "wwan-info.h"
 #include "wwan/phosh-wwan-ofono.h"
 #include "wwan/phosh-wwan-mm.h"
 #include "wwan/phosh-wwan-backend.h"
@@ -149,6 +150,7 @@ typedef struct
   PhoshRunCommandManager *run_command_manager;
   PhoshNetworkAuthManager *network_auth_manager;
   PhoshVpnManager *vpn_manager;
+  PhoshPortalAccessManager *portal_access_manager;
 
   /* sensors */
   PhoshSensorProxyManager *sensor_proxy_manager;
@@ -361,6 +363,7 @@ phosh_shell_dispose (GObject *object)
   g_clear_object (&priv->notification_banner);
 
   /* dispose managers in opposite order of declaration */
+  g_clear_object (&priv->portal_access_manager);
   g_clear_object (&priv->vpn_manager);
   g_clear_object (&priv->network_auth_manager);
   g_clear_object (&priv->run_command_manager);
@@ -573,6 +576,7 @@ setup_idle_cb (PhoshShell *self)
   priv->splash_manager = phosh_splash_manager_new (priv->app_tracker);
   priv->run_command_manager = phosh_run_command_manager_new();
   priv->network_auth_manager = phosh_network_auth_manager_new ();
+  priv->portal_access_manager = phosh_portal_access_manager_new ();
 
   /* Delay signaling the compositor a bit so that idle handlers get a
    * chance to run and the user has can unlock right away. Ideally
