@@ -29,3 +29,6 @@ gboolean         phosh_error_warnv (const char  *log_domain,
                                     int          code,
                                     const gchar *fmt,
                                     ...) G_GNUC_PRINTF(5, 6);
+int              phosh_create_shm_file (off_t size);
+char            *phosh_util_escape_markup (const char *markup, gboolean allow_markup);
+char            *phosh_util_local_date (void);
